package cn.com.infosec.asn1;

import java.io.IOException;
import java.io.InputStream;

public class BERTaggedObjectParser implements ASN1TaggedObjectParser {
   private int _baseTag;
   private int _tagNumber;
   private InputStream _contentStream;
   private boolean _indefiniteLength;

   protected BERTaggedObjectParser(int baseTag, int tagNumber, InputStream contentStream) {
      this._baseTag = baseTag;
      this._tagNumber = tagNumber;
      this._contentStream = contentStream;
      this._indefiniteLength = contentStream instanceof IndefiniteLengthInputStream;
   }

   private ASN1EncodableVector rLoadVector(InputStream in) {
      try {
         return (new ASN1StreamParser(in)).readVector();
      } catch (IOException var2) {
         throw new IllegalStateException(var2.getMessage());
      }
   }

   public boolean isConstructed() {
      return (this._baseTag & 32) != 0;
   }

   public int getTagNo() {
      return this._tagNumber;
   }

   public DEREncodable getObjectParser(int tag, boolean isExplicit) {
      if (isExplicit) {
         return (new ASN1StreamParser(this._contentStream)).readObject();
      } else if (tag != 4) {
         if (tag != 16) {
            if (tag == 17) {
               return (DEREncodable)(this._indefiniteLength ? new BERSetParser(new ASN1StreamParser(this._contentStream)) : new DERSetParser(new ASN1StreamParser(this._contentStream)));
            } else {
               throw new RuntimeException("implicit tagging not implemented");
            }
         } else {
            return (DEREncodable)(this._indefiniteLength ? new BERSequenceParser(new ASN1StreamParser(this._contentStream)) : new DERSequenceParser(new ASN1StreamParser(this._contentStream)));
         }
      } else {
         return (DEREncodable)(!this._indefiniteLength && !this.isConstructed() ? new DEROctetStringParser((DefiniteLengthInputStream)this._contentStream) : new BEROctetStringParser(new ASN1StreamParser(this._contentStream)));
      }
   }

   public DERObject getDERObject() {
      int var8;
      ASN1EncodableVector var9;
      DEREncodable var10;
      if (this._indefiniteLength) {
         BERTaggedObject var12;
         BERTaggedObject var17;
         if ((var9 = this.rLoadVector(this._contentStream)).size() == 1) {
            var17 = var12 = new BERTaggedObject;
            var8 = this._tagNumber;
            var10 = var9.get(0);
            var17.<init>(true, var8, var10);
         } else {
            var17 = var12 = new BERTaggedObject;
            var8 = this._tagNumber;
            BERSequence var13 = BERFactory.createSequence(var9);
            var17.<init>(false, var8, var13);
         }

         return var12;
      } else {
         DERTaggedObject var15;
         if (this.isConstructed()) {
            DERTaggedObject var2;
            if ((var9 = this.rLoadVector(this._contentStream)).size() == 1) {
               var15 = var2 = new DERTaggedObject;
               var8 = this._tagNumber;
               var10 = var9.get(0);
               var15.<init>(true, var8, var10);
            } else {
               var15 = var2 = new DERTaggedObject;
               var8 = this._tagNumber;
               DERSequence var11 = DERFactory.createSequence(var9);
               var15.<init>(false, var8, var11);
            }

            return var2;
         } else {
            IOException var10000;
            label49: {
               DefiniteLengthInputStream var14;
               boolean var10001;
               try {
                  var14 = (DefiniteLengthInputStream)this._contentStream;
               } catch (IOException var5) {
                  var10000 = var5;
                  var10001 = false;
                  break label49;
               }

               DefiniteLengthInputStream var1 = var14;

               try {
                  var15 = new DERTaggedObject;
               } catch (IOException var4) {
                  var10000 = var4;
                  var10001 = false;
                  break label49;
               }

               DERTaggedObject var16 = var15;
               BERTaggedObjectParser var10002 = this;
               boolean var6 = false;

               try {
                  var16.<init>(var6, var10002._tagNumber, new DEROctetString(var1.toByteArray()));
                  return var15;
               } catch (IOException var3) {
                  var10000 = var3;
                  var10001 = false;
               }
            }

            IOException var7 = var10000;
            throw new IllegalStateException(var7.getMessage());
         }
      }
   }
}
